<?php namespace Site21\ShopaholicPopularOffers;

use Backend;
use System\Classes\PluginBase;
use Event;
use Site21\ShopaholicPopularOffers\Classes\Event\Product\ExtendProductFieldsHandler;
use Site21\ShopaholicPopularOffers\Classes\Event\Product\ExtendProductModel;
use Site21\ShopaholicPopularOffers\Models\Settings;
use Config;
use Lovata\Shopaholic\Models\Product;

/**
 * ShopaholicPopularOffers Plugin Information File
 */
class Plugin extends PluginBase
{
	
	public function registerSettings()
	{
	    return [
	        'settings' => [
	            'label'       => 'Популярные товары',
	            'description' => 'Настройка баллов популярности за действия',
	            'category'    => 'Магазин',
	            'icon'        => 'icon-line-chart',
	            'class'       => 'Site21\ShopaholicPopularOffers\Models\Settings',
	            'order'       => 500,
	            'keywords'    => 'popular product offer популярный товар',
	            'permissions' => ['site21.shopaholicpopularoffers.access_settings']
	        ]
	    ];
	}
    /**
     * Returns information about this plugin.
     *
     * @return array
     */
    public function pluginDetails()
    {
        return [
            'name'        => 'ShopaholicPopularOffers',
            'description' => 'Просмтой плагин добавления рейтинга популярости товаров за просмотр, добавление в корзину, оформление товаров.',
            'author'      => 'Site21',
            'icon'        => 'icon-leaf',
            'homepage'    => 'https://blog.site21.ru'
        ];
    }

    /**
     * Register method, called when the plugin is first registered.
     *
     * @return void
     */
    public function register()
    {

    }

    /**
     * Boot method, called right before the request route.
     *
     * @return array
     */
    public function boot()
    {
    	Event::subscribe(ExtendProductFieldsHandler::class);
    	Event::subscribe(ExtendProductModel::class);
    	
		Event::listen('shopaholic.sorting.get.list', function($sSorting) {
		    if ($sSorting != 'popularity|desc') {
		        return null;
		    }
		    
		    // Получите массив со списком id товаров для кастомной сортировки по полурности
		    $arElementIDList = (array) Product::orderBy('popularity', 'desc')->lists('id');
		    
		    return $arElementIDList;
		});
    	
		// Событие при просмотре товара
		Event::listen('site21.shopaholicpopularoffers.productShow', function($id) {
			$is_admin = \BackendAuth::check();
			if(!$is_admin) {
				$product = Product::find($id);
				$product->popularity += Settings::get('offer_view');
				$product->save();
			}
		});
		
		// Событие оформления заказа
		Event::listen(\Lovata\OrdersShopaholic\Classes\Processor\OrderProcessor::EVENT_ORDER_CREATED, function($obOrder) {
			$is_admin = \BackendAuth::check();
			if(!$is_admin) {
			    // Получаем оформленные товары
			    $obOrderPositionList = $obOrder->order_position;
			    foreach($obOrderPositionList as $obOrderPosition) {
					// Получаем оффер
					$obOffer = $obOrderPosition->offer;
					// Получаем его товар
					$obProduct = $obOffer->product;
					
					// Редактируем товар и добавляем рейтинг
				 	$product = Product::find($obProduct->id);
				 	$product->popularity += Settings::get('offer_zakaz');
				 	$product->save();
			    }
			}
		});
		
		Event::listen('site21.shopaholicpopularoffers.productAddToCart', function($id) {
			$is_admin = \BackendAuth::check();
			if(!$is_admin) {
				$product = Product::find($id);
				$product->popularity += Settings::get('offer_add_to_cart');
				$product->save();
			}
		});
    }

    /**
     * Registers any front-end components implemented in this plugin.
     *
     * @return array
     */
    public function registerComponents()
    {

        return [
            'Site21\ShopaholicPopularOffers\Components\ShopaholicPopularOffer' => 'ShopaholicPopularOffer',
        ];
    }

    /**
     * Registers any back-end permissions used by this plugin.
     *
     * @return array
     */
    public function registerPermissions()
    {
        return [
            'site21.shopaholicpopularoffers.access_settings' => [
                'tab' => 'ShopaholicPopularOffers',
                'label' => 'Редактировать настройки популярных товаров'
            ],
        ];
    }

    /**
     * Registers back-end navigation items for this plugin.
     *
     * @return array
     */
    public function registerNavigation()
    {
        return []; // Remove this line to activate

        return [
            'shopaholicpopularoffers' => [
                'label'       => 'ShopaholicPopularOffers',
                'url'         => Backend::url('site21/shopaholicpopularoffers/mycontroller'),
                'icon'        => 'icon-leaf',
                'permissions' => ['site21.shopaholicpopularoffers.*'],
                'order'       => 500,
            ],
        ];
    }
}
